@@ -1,6 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: inst-abbr-ids.pl
-# ABSTRACT: Abbreviate seq ids in FASTA files
+# ABSTRACT: Abbreviate seq ids in FASTA files (optimized)
+# CONTRIBUTOR: Valerian LUPO <valerian.lupo@doct.uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -16,6 +17,7 @@ use Bio::MUST::Core::Utils qw(secure_outfile);
 use aliased 'Bio::MUST::Core::Ali';
 use aliased 'Bio::MUST::Core::IdMapper';
 
+# TODO add optional %seen hash, either global or filewise and either .1, .2 etc or .2, .3 etc
 # TODO: make things more souple
 # perl -nle 'if ( ($prot,$gca) = m/^>(\S+).*:(GC[AF]_[^:]+)/ ) { print q{>} . $gca . q{|} . $prot } else { print }' hexa-900-p-a_prot_cplt.fa > hexa-900-p-a_prot_cplt_abbr2.fa
 
@@ -45,27 +47,25 @@ if ($ARGV_id_prefix_mapper) {
     $prefix_mapper = IdMapper->load($ARGV_id_prefix_mapper);
 }
 
-my $prefix;     # global variable that will be updated for each infile
+# global variables that will be updated for each infile
+my $prefix;
+my @long_ids;
+my @abbr_ids;
 
 my $abbrid_filter = sub {
     my $seq = shift;
+
+    # get long id
     my $long_id = $seq->full_id;
+    push @long_ids, $long_id;
 
-    # abbreviate seq_id (using code from Roles::Listable::regex_mapper)
-    # TODO: refactor in module
-    my @ids = $long_id =~ $regex;               # capture original id(s)
-    s{$NOID_CHARS}{_}xmsg for @ids;             # substitute forbidden chars
-    my $abbr_id = join q{}, $prefix, @ids;
-
-    # store allowed seqs (optonally unwrapped)
-    # TODO: refactor in module
-    my $width = $seq->seq_len;
-    my $chunk = $ARGV_nowrap ? $width : 60;     # optionally disable wrap
+    # abbreviate seq_id
+    my $abbr_id = $seq->seq_id->abbr_with_regex($prefix, $regex);
+    push @abbr_ids, $abbr_id;
 
+    # store allowed seqs
     my $str = '>' . $abbr_id . "\n";            # use abbreviated seq_id
-    for (my $site = 0; $site < $width; $site += $chunk) {
-        $str .= $seq->edit_seq($site, $chunk) . "\n";
-    }
+    $str .= $seq->wrapped_str;
 
     return $str;
 };
@@ -84,10 +84,22 @@ for my $infile (@ARGV_infiles) {
     $prefix .= '|';
 
     my $outfile = secure_outfile( file($dir, $infile), '-abbr');
-
     Ali->instant_store(
         $outfile, { infile => $infile, coderef => $abbrid_filter }
     );
+
+    # optionally store the id mapper
+    if ($ARGV_store_id_mapper) {
+        my $idmfile = change_suffix($outfile, '.idm');
+        my $id_mapper = IdMapper->new(
+            long_ids => \@long_ids, abbr_ids => \@abbr_ids
+        );
+        $id_mapper->store($idmfile);
+    }
+
+    # reset arrays for next infile
+    @long_ids = ();
+    @abbr_ids = ();
 }
 
 __END__
@@ -96,11 +108,11 @@ __END__
 
 =head1 NAME
 
-inst-abbr-ids.pl - Abbreviate seq ids in FASTA files
+inst-abbr-ids.pl - Abbreviate seq ids in FASTA files (optimized)
 
 =head1 VERSION
 
-version 0.202310
+version 0.212530
 
 =head1 USAGE
 
@@ -142,7 +154,7 @@ following predefined regexes are available (assuming a leading '>'):
 =item --outdir=<dir>
 
 Optional output dir that will contain the abbreviated FASTA files (will be
-created if needed) [default: none]. Otherwise, output file are in the same
+created if needed) [default: none]. Otherwise, output files are in the same
 directory as input files.
 
 =for Euclid: dir.type: writable
@@ -163,9 +175,9 @@ String to use as the seq id prefix (e.g., NCBI taxon id, 4-letter code)
 
 =for Euclid: str.type: string
 
-=item --[no]wrap
+=item --store-id-mapper
 
-[Don't] wrap sequences [default: yes].
+Store the IDM file corresponding to each output file [default: no].
 
 =item --version
 
@@ -183,6 +195,12 @@ Print the usual program information
 
 Denis BAURAIN <denis.baurain@uliege.be>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Valerian LUPO
+
+Valerian LUPO <valerian.lupo@doct.uliege.be>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by University of Liege / Unit of Eukaryotic Phylogenomics / Denis BAURAIN.
