@@ -1,6 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: inst-qual-filter.pl
-# ABSTRACT: Discard low-quality nt seqs in FASTA files
+# ABSTRACT: Discard low-quality nt seqs in FASTA files (optimized)
+# CONTRIBUTOR: Valerian LUPO <valerian.lupo@doct.uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -20,23 +21,15 @@ my $purity_filter = sub {
     my $seq = shift;
 
     # compute purity
-    # TODO: refactor in module
-    (my $pure_seq = $seq->seq) =~ s/$NONPUREDNA//xmsg;
-    my $purity = 1.0 * length($pure_seq) / $seq->seq_len;
+    my $purity = $seq->purity;
     if ($purity < $ARGV_min_purity) {
         push @bad_seqs, $seq;
         return;
     }
 
-    # store allowed seqs (optonally unwrapped)
-    # TODO: refactor in module
-    my $width = $seq->seq_len;
-    my $chunk = $ARGV_nowrap ? $width : 60;     # optionally disable wrap
-
+    # store allowed seqs
     my $str = '>' . $seq->full_id . "\n";
-    for (my $site = 0; $site < $width; $site += $chunk) {
-        $str .= $seq->edit_seq($site, $chunk) . "\n";
-    }
+    $str .= $seq->wrapped_str;
 
     return $str;
 };
@@ -64,11 +57,11 @@ __END__
 
 =head1 NAME
 
-inst-qual-filter.pl - Discard low-quality nt seqs in FASTA files
+inst-qual-filter.pl - Discard low-quality nt seqs in FASTA files (optimized)
 
 =head1 VERSION
 
-version 0.202310
+version 0.212530
 
 =head1 USAGE
 
@@ -113,10 +106,6 @@ ambiguous, missing and gap-like character states) are considered as non-pure.
 =for Euclid: n.type:    number
     n.default: 1
 
-=item --[no]wrap
-
-[Don't] wrap sequences [default: yes].
-
 =item --version
 
 =item --usage
@@ -133,6 +122,12 @@ Print the usual program information
 
 Denis BAURAIN <denis.baurain@uliege.be>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Valerian LUPO
+
+Valerian LUPO <valerian.lupo@doct.uliege.be>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by University of Liege / Unit of Eukaryotic Phylogenomics / Denis BAURAIN.
